### join_counts_local

Compute Local Join Counts statistics.

- Tool: `join_counts_local`

Parameters

- shapefile_path (string)
- dependent_var (string, default "LAND_USE")
- target_crs (string, default "EPSG:4326")
- distance_threshold (number)

Returns

- local_join_counts[]; data_preview[]; status, message
